@@ -192,6 +192,7 @@
 #define HAVE_PTHREAD_ATTR_SETSCOPE 1
 #define HAVE_PTHREAD_ATTR_SETSTACKSIZE 1
 /* #undef HAVE_PTHREAD_CONDATTR_CREATE */
+/* #undef HAVE_PTHREAD_GETAFFINITY_NP */
 #define HAVE_PTHREAD_KEY_DELETE 1
 /* #undef HAVE_PTHREAD_KILL */
 #define HAVE_PTHREAD_RWLOCK_RDLOCK 1
@@ -240,7 +241,6 @@
 /* Symbols we may use */
 /* #undef HAVE_SYS_ERRLIST */
 /* used by stacktrace functions */
-#define HAVE_BSS_START 1
 /* #undef HAVE_BACKTRACE */
 /* #undef HAVE_BACKTRACE_SYMBOLS */
 /* #undef HAVE_BACKTRACE_SYMBOLS_FD */
@@ -534,16 +534,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 4
-#define MYSQL_VERSION_PATCH 12
+#define MYSQL_VERSION_PATCH 15
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.4.12"
+#define PACKAGE_STRING "MySQL Server 10.4.15"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.4.12"
-#define VERSION "10.4.12"
+#define PACKAGE_VERSION "10.4.15"
+#define VERSION "10.4.15"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
