@@ -199,9 +199,9 @@
 #define HAVE_PTHREAD_SIGMASK 1
 /* #undef HAVE_PTHREAD_YIELD_NP */
 #define HAVE_PTHREAD_YIELD_ZERO_ARG 1
-/* #undef PTHREAD_ONCE_INITIALIZER */
+#define PTHREAD_ONCE_INITIALIZER PTHREAD_ONCE_INIT
 #define HAVE_PUTENV 1
-/* #undef HAVE_READDIR_R */
+#define HAVE_READDIR_R 1
 #define HAVE_READLINK 1
 #define HAVE_REALPATH 1
 #define HAVE_RENAME 1
@@ -241,7 +241,6 @@
 /* Symbols we may use */
 /* #undef HAVE_SYS_ERRLIST */
 /* used by stacktrace functions */
-#define HAVE_BSS_START 1
 /* #undef HAVE_BACKTRACE */
 /* #undef HAVE_BACKTRACE_SYMBOLS */
 /* #undef HAVE_BACKTRACE_SYMBOLS_FD */
@@ -535,16 +534,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 4
-#define MYSQL_VERSION_PATCH 13
+#define MYSQL_VERSION_PATCH 15
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.4.13"
+#define PACKAGE_STRING "MySQL Server 10.4.15"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.4.13"
-#define VERSION "10.4.13"
+#define PACKAGE_VERSION "10.4.15"
+#define VERSION "10.4.15"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
